@@ -294,7 +294,12 @@ opencal()
 	int fd, pdes[2];
 
 	/* open up calendar file as stdin */
-	if (!freopen("calendar", "r", stdin)) {
+	if (!freopen("calendar", "r", stdin)
+#ifdef DEBIAN
+	&& !freopen(".calendar", "r", stdin)
+	&& (doall || !freopen(_PATH_CALENDAR, "r", stdin))
+#endif /* DEBIAN */
+	) {
 		if (doall)
 			return (NULL);
 		errx(1, "no calendar file.");
