@@ -35,15 +35,15 @@
 
 #include <paths.h>
 
-#ifdef __linux__
-#define _PATH_WORDS	"/usr/dict/words"
-#else /* not __linux__ */
 #define	_PATH_WORDS	"/usr/share/dict/words"
-#endif /* not __linux__ */
+#ifdef __linux__
+#define _PATH_WORDS2	"/usr/dict/words"
+#endif /* __linux__ */
 
 #define	_PATH_CPP	"/usr/bin/cpp"
 			/* XXX -- fix when cpp parses arguments rationally */
 #ifdef __linux__
+#define _PATH_CALENDAR  "/usr/lib/calendar/default"
 #define _PATH_INCLUDE	"-I/usr/lib/calendar"
 #define _PATH_YEARINC	"-I/usr/lib/calendar/%d"
 #else /* not __linux__ */
