@@ -99,6 +99,23 @@ DB *db;
 
 char from[MAXLINE];
 
+
+/* read stdin and throw away everything we receive.  This keeps
+ * mailers which are delivering to a pipe happy that we've deal with
+ * the message sucessfully. */
+discard_exit()
+{
+    char buf[1024];
+    int ret;
+
+    do {
+	ret = fread(buf, sizeof(char), 1024, stdin);
+    } while(ret > 0 && !feof(stdin));
+
+    /* we exit, whether error happened while reading or not */
+    exit(0);
+}
+
 main(argc, argv)
 	int argc;
 	char **argv;
@@ -216,7 +233,7 @@ readheaders()
 				if (p = index(from, '\n'))
 					*p = '\0';
 				if (junkmail())
-					exit(0);
+					discard_exit();
 			}
 			break;
 		case 'P':		/* "Precedence:" */
@@ -232,7 +249,7 @@ readheaders()
 			if (!strncasecmp(p, "junk", 4) ||
 			    !strncasecmp(p, "bulk", 4) ||
 			    !strncasecmp(p, "list", 4))
-				exit(0);
+				discard_exit();
 			break;
 		case 'C':		/* "Cc:" */
 			if (strncmp(buf, "Cc:", 3))
@@ -253,7 +270,7 @@ findme:			for (cur = names; !tome && cur; cur = cur->next)
 				tome += nsearch(cur->name, buf);
 		}
 	if (!tome)
-		exit(0);
+		discard_exit();
 	if (!*from) {
 		syslog(LOG_NOTICE, "vacation: no initial \"From\" line.\n");
 		exit(1);
